merkle_add_local

Function merkle_add_local 

pub(crate) fn merkle_add_local(
    ctx: FunctionEnvMut<'_, Env>,
    ptr: WasmPtr<u8>,
    ptr_len: u32,
) -> i64
Add data to a tx-local Merkle tree.

Expects:

  • db_info: Handle where the Merkle tree is stored
  • db_roots: Handle where all new Merkle roots are stored
  • root_key: Serialized key pointing to latest root in db_info
  • tree_key: Serialized key pointing to the Merkle tree in db_info
  • coins: Items we want to add to the Merkle tree

Permissions

  • ContractSection::Update